===================================================
django-content-editor -- Editing structured content
===================================================

`Documentation on Read the Docs <http://django-content-editor.readthedocs.org/en/latest/>`_

.. image:: https://github.com/matthiask/django-content-editor/actions/workflows/tests.yml/badge.svg
    :target: https://github.com/matthiask/django-content-editor/
    :alt: CI Status

.. image:: https://readthedocs.org/projects/django-content-editor/badge/?version=latest
    :target: https://django-content-editor.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status
